@@ -17,8 +17,15 @@ m <- c(1,1)
 sd <- 3
 
 ## exact value of the integral over the _polygonal_ circle
-gpclibPermit()
-intExact <- polyCub.exact.Gauss(disc.owin, mean=m, Sigma=sd^2*diag(2))
+intExact <- 0.65844436
+if (requireNamespace("mvtnorm") && gpclibPermit()) {
+    ## run this conditionally since gpclib might not be available on all
+    ## platforms (as pointed out by Uwe Ligges, 2014-04-20)
+    test_that("polyCub.exact.Gauss returns validated result", {
+        int <- polyCub.exact.Gauss(disc.owin, mean=m, Sigma=sd^2*diag(2))
+        expect_that(int, equals(intExact, tolerance=1e-8, check.attributes=FALSE))
+    })
+}
 
 
 ### perform the tests (check against each other)
@@ -39,8 +46,10 @@ test_that("midpoint-cubature is correct", {
 })
 
 test_that("SV-cubature is correct", {
-    int <- polyCub.SV(disc.owin, f, mean=m, sd=sd, nGQ=3)
-    expect_that(int, equals(intExact, tolerance=0.0001, check.attributes=FALSE))
+    intC <- polyCub.SV(disc.owin, f, mean=m, sd=sd, nGQ=3, engine="C")
+    intR <- polyCub.SV(disc.owin, f, mean=m, sd=sd, nGQ=3, engine="R")
+    expect_that(intC, equals(intR))
+    expect_that(intC, equals(intExact, tolerance=0.0001, check.attributes=FALSE))
 })
 
 test_that("isotropic cubature is correct", {
